@@ -1,22 +1,47 @@
-#!/usr/bin/env python 
-'''
-magic.py
- determines a file type by its magic number
-
- (C)opyright 2000 Jason Petrone <jp_py@demonseed.net>
- All Rights Reserved
-
- Command Line Usage: running as `python magic.py file` will print
-                     a description of what 'file' is.
-
- Module Usage:
-     magic.whatis(data): when passed a string 'data' containing 
-                         binary or text data, a description of
-                         what the data is will be returned.
-
-     magic.mime_type(filename): returns a description of what the file
-                           '    filename' contains.
-'''
+# -*- coding: utf-8 -*-
+#
+# magic.py
+# determines a file type by its magic number
+#
+# Copyright (c) 2000, Jason Petrone <jp_py@demonseed.net>
+# All Rights Reserved
+#
+# Modifications by Don Welch
+# (c) Copyright 2003-2006 Hewlett-Packard Development Company, L.P.
+#  
+# Redistribution and use in source and binary forms, with or without modification, 
+# are permitted provided that the following conditions are met:
+# 
+#     * Redistributions of source code must retain the above copyright notice, 
+#     this list of conditions and the following disclaimer.
+#     * Redistributions in binary form must reproduce the above copyright notice, 
+#     this list of conditions and the following disclaimer in the documentation and/or 
+#     other materials provided with the distribution.
+#     * Neither the name of the <ORGANIZATION> nor the names of its contributors may 
+#     be used to endorse or promote products derived from this software without 
+#     specific prior written permission.
+# 
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
+# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
+# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
+# IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
+# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
+# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
+# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
+# STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
+# THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+# 
+#  Command Line Usage: running as `python magic.py file` will print
+#                      a description of what 'file' is.
+# 
+#  Module Usage:
+#      magic.whatis(data): when passed a string 'data' containing 
+#                          binary or text data, a description of
+#                          what the data is will be returned.
+# 
+#      magic.mime_type(filename): returns a description of what the file
+#                            '    filename' contains.
+# 
 
 import re, struct
 
@@ -443,6 +468,7 @@ magic = [
   [0L, 'string', '=', 'yx', 'MGR bitmap, modern format, squeezed'],
   [0L, 'string', '=', '%bitmap\000', 'FBM image data'],
   [1L, 'string', '=', 'PC Research, Inc', 'group 3 fax data'],
+  [0L, 'string', '=', 'hplip_g3', 'application/hplip-fax'],
   [0L, 'beshort', '=', 65496L, 'image/jpeg'],
   [0L, 'string', '=', 'hsi1', 'image/x-jpeg-proprietary'],
   [0L, 'string', '=', 'BM', 'image/x-bmp'],
@@ -1149,8 +1175,9 @@ def whatis(data):
     if ord(c) > 128:
       return 'data'
   # its ASCII, now do text tests
-  if data.find('def ', 0, 8192) > -1:
-    return 'application/x-python'
+  if data.find('!/usr/bin/env python', 0, 256) > -1 or \
+    data.find('def ', 0, 8192) > -1:
+      return 'application/x-python'
 
   return "text/plain"
 
