@@ -206,7 +206,7 @@ int Dot4Channel::Dot4ReverseCmd(int fd)
    {
       if ((len = pDev->Read(fd, pBuf, size)) < 0)
       {
-         syslog(LOG_ERR, "unable to read Dot4ReverseCmd data: %m %s %d\n", __FILE__, __LINE__);
+         syslog(LOG_ERR, "unable to read Dot4ReverseCmd data: %m exp=%zd act=%zd %s %d\n", pklen-sizeof(DOT4Header), pklen-sizeof(DOT4Header)-size, __FILE__, __LINE__);
          stat = 1;
          goto bugout;
       }
@@ -240,9 +240,9 @@ int Dot4Channel::Dot4ReverseReply(int fd, unsigned char *buf, int bufsize)
       size = sizeof(DOT4Header);
       while (size > 0)
       {
-         if ((len = pDev->Read(fd, pBuf, size, 2, 0)) < 0)   /* wait 2 second */
+         if ((len = pDev->Read(fd, pBuf, size, 4000000)) < 0)   /* wait 4 seconds, 2 fails on PS2575 1200dpi uncompressed scanning  */
          {
-            syslog(LOG_ERR, "unable to read Dot4ReverseReply header: %m %s %d\n", __FILE__, __LINE__);
+            syslog(LOG_ERR, "unable to read Dot4ReverseReply header: %m bytesRead=%zd %s %d\n", sizeof(DOT4Header)-size, __FILE__, __LINE__);
             stat = 2;  /* short timeout */
             goto bugout;
          }
@@ -252,13 +252,6 @@ int Dot4Channel::Dot4ReverseReply(int fd, unsigned char *buf, int bufsize)
 
       /* Determine packet size. */
       pklen = ntohs(pPk->h.length);
-      if (pklen > bufsize)
-      {
-         syslog(LOG_ERR, "invalid Dot4ReverseReply packet size: size=%d, buf=%d %s %d\n", pklen, bufsize, __FILE__, __LINE__);
-         stat = 1;
-         goto bugout;
-      }
-
       if (pklen <= 0 || pklen > bufsize)
       {
          syslog(LOG_ERR, "invalid Dot4ReverseReply packet size: size=%d, buf=%d %s %d\n", pklen, bufsize, __FILE__, __LINE__);
@@ -272,7 +265,7 @@ int Dot4Channel::Dot4ReverseReply(int fd, unsigned char *buf, int bufsize)
       {
          if ((len = pDev->Read(fd, pBuf, size)) < 0)
          {
-            syslog(LOG_ERR, "unable to read Dot4ReverseReply data: %m %s %d\n", __FILE__, __LINE__);
+            syslog(LOG_ERR, "unable to read Dot4ReverseReply data: %m exp=%zd act=%zd %s %d\n", pklen-sizeof(DOT4Header), pklen-sizeof(DOT4Header)-size, __FILE__, __LINE__);
             stat = 1;
             goto bugout;
          }
@@ -333,6 +326,20 @@ int Dot4Channel::Dot4Init(int fd)
             cnt++;
             continue;
          }
+         if (stat == 2 && cnt<1)
+         {
+            /* hack for Fullhouse, Swami and Northstar */
+            syslog(LOG_INFO, "invalid DOT4InitReply retrying command... %s %d\n", __FILE__, __LINE__);
+            memset(buf, 0, sizeof(DOT4Init));
+            n = sizeof(DOT4Init);
+            pCmd->h.length = htons(n);
+            pCmd->h.credit = 1;       /* transaction credit for reply */
+            pCmd->cmd = DOT4_INIT;
+            pCmd->rev = 0x20;
+            pDev->Write(fd, pCmd, n);
+            cnt++;
+            continue;
+         }
          syslog(LOG_ERR, "invalid DOT4InitReply: cmd=%x, result=%x\n, revision=%x %s %d\n", pReply->cmd, pReply->result, pReply->rev, __FILE__, __LINE__);
          stat = 1;
          goto bugout;
@@ -467,15 +474,15 @@ int Dot4Channel::Dot4ReverseData(int fd, int sockid, unsigned char *buf, int len
       {
          /* Use requested client timeout until we start reading. */
          if (total == 0)
-            len = pDev->Read(fd, buf+total, size, timeout, 0);
+            len = pDev->Read(fd, buf+total, size, timeout);
          else
             len = pDev->Read(fd, buf+total, size);
 
          if (len < 0)
          {
-            /* Got a timeout, if timeout occured after read started thats an error. */
-            if (total > 0)
-               syslog(LOG_ERR, "unable to read Dot4ReverseData header: %m %s %d\n", __FILE__, __LINE__);
+            /* Got a timeout, if exception timeout or timeout occured after read started thats an error. */
+            if (timeout >= EXCEPTION_TIMEOUT || total > 0)
+               syslog(LOG_ERR, "unable to read Dot4ReverseData header: %m %s %s %d\n", pDev->GetURI(), __FILE__, __LINE__);
             goto bugout;
          }
          size-=len;
@@ -525,7 +532,7 @@ int Dot4Channel::Dot4ReverseData(int fd, int sockid, unsigned char *buf, int len
 
       total = 0;  /* eat packet header */
    
-      /* Read packet data field without exception_timeout. */
+      /* Read packet data field with exception_timeout. */
       while (size > 0)
       {
          if ((len = pDev->Read(fd, buf+total, size)) < 0)
@@ -602,7 +609,7 @@ int Dot4Channel::Dot4CloseChannel(int fd)
    pCmd->cmd = DOT4_CLOSE_CHANNEL;
    pCmd->psocket = GetSocketID();
    pCmd->ssocket = GetSocketID();
-   
+
    if ((len = pDev->Write(fd, pCmd, n)) != n)
    {
       syslog(LOG_ERR, "unable to write Dot4CloseChannel: %m %s %d\n", __FILE__, __LINE__);
@@ -707,12 +714,9 @@ bugout:
 
 int Dot4Channel::Open(char *sendBuf, int *result)
 {
-   char res[] = "msg=OpenChannelResult\nresult-code=%d\n";
-   int supportedProtocols=0;
-   int twoints[2];
-   int len, slen;
-   unsigned int i;
-   unsigned char buf[255];
+   const char res[] = "msg=OpenChannelResult\nresult-code=%d\n";
+   int slen, fd;
+   int config, interface, altset;
 
    *result = R_IO_ERROR;
    slen = sprintf(sendBuf, res, R_IO_ERROR);  
@@ -723,56 +727,50 @@ int Dot4Channel::Open(char *sendBuf, int *result)
       /* Initialize DOT4 transport if this is the first DOT4 channel. */
       if (pDev->ChannelCnt==1)
       {
-         /* Get current USB protocol. */
-         if (ioctl(pDev->GetOpenFD(), LPIOC_GET_PROTOCOLS, &twoints) < 0)
-         {
-            syslog(LOG_ERR, "unable to get %s protocols: %m %s %d\n", pDev->GetURI(), __FILE__, __LINE__);
-            goto bugout;
-         }
-         pDev->CurrentProtocol=twoints[0];
-         supportedProtocols=twoints[1]; 
-
          /* If 7/1/3 (MLC/1284.4) protocol is available use it. */
-         if (supportedProtocols & (1<<USB_PROTOCOL_713))
-         {
-            if (ioctl(pDev->GetOpenFD(), LPIOC_SET_PROTOCOL, USB_PROTOCOL_713) < 0) 
-            {
-               syslog(LOG_ERR, "unable to set %s 7/1/3: %m %s %d\n", pDev->GetURI(), __FILE__, __LINE__);
-               goto bugout;
-            }
-            pDev->NewProtocol = USB_PROTOCOL_713;
-         }
-         else if (supportedProtocols & (1<<USB_PROTOCOL_712))
-         { 
-            /* Emulate 7/1/3 on 7/1/2 using vendor-specific ECP channel-77. */
-            if (ioctl(pDev->GetOpenFD(), LPIOC_SET_PROTOCOL, USB_PROTOCOL_712) < 0) 
-            {
-               syslog(LOG_ERR, "unable to set %s 7/1/2: %m %s %d\n", pDev->GetURI(), __FILE__, __LINE__);
-               goto bugout;
-            }
-            if (ioctl(pDev->GetOpenFD(), LPIOC_HP_SET_CHANNEL, 77) < 0) 
-            {
-               syslog(LOG_ERR, "unable to set %s chan77: %m %s %d\n", pDev->GetURI(), __FILE__, __LINE__);
-               goto bugout;
-            }
-            pDev->NewProtocol = USB_PROTOCOL_712;
-         }
+         if (pDev->GetInterface(7, 1, 3, &config, &interface, &altset) == 0)
+            fd = FD_7_1_3;    /* mlc, dot4 */
          else
+            fd = FD_7_1_2;    /* raw, mlc, dot4 */
+
+         /* If new usb interface, release old and claim new. */
+         if (pDev->OpenFD != fd)
          {
-            syslog(LOG_ERR, "unable to set %s MLC/1284.4: not supported %s %d\n", pDev->GetURI(), __FILE__, __LINE__);
-            goto bugout;
+            pDev->ReleaseInterface(pDev->OpenFD);
+            if (pDev->ClaimInterface(fd, config, interface, altset))
+               goto bugout;
+            pDev->OpenFD = fd;
          }
 
-#ifdef HPIOD_DEBUG
-            syslog(LOG_INFO, "currentProtocol=%x supportedProtocols=%x newProtocol=%x: %s %d\n", pDev->CurrentProtocol, supportedProtocols, pDev->NewProtocol, __FILE__, __LINE__);
-#endif
+         if (fd == FD_7_1_2)
+         { 
+            if (pDev->GetChannelMode() == DOT4_BRIDGE_MODE)
+            {
+               /* Emulate 7/1/3 on 7/1/2 using the bridge chip set (ie: CLJ2500). */
+               if (pDev->BridgeChipUp(fd))
+                  goto bugout;
+            }
+            else
+            {
+               /* Emulate 7/1/3 on 7/1/2 using vendor-specific ECP channel-77. */
+               if (pDev->WriteECPChannel(fd, 77)) 
+                  goto bugout;
+            }
+         }
+
+         if (fd == FD_7_1_3 && pDev->GetChannelMode() == DOT4_PHOENIX_MODE && strcasecmp(GetService(), "hp-message") == 0)
+            pDev->WritePhoenixSetup(fd);
+
+         int len;
+         unsigned int i;
+         unsigned char buf[255];
 
          /* Drain any reverse data. */
          for (i=0,len=1; len > 0 && i < sizeof(buf); i++)
-            len = pDev->Read(pDev->GetOpenFD(), buf+i, 1, 0, 0);    /* no blocking */
+            len = pDev->Read(fd, buf+i, 1, 0);    /* no blocking */
 
          /* DOT4 initialize */
-         if (Dot4Init(pDev->GetOpenFD()) != 0)
+         if (Dot4Init(fd) != 0)
             goto bugout;
 
          pDev->MlcUp=1;
@@ -797,9 +795,9 @@ bugout:
 
 int Dot4Channel::Close(char *sendBuf, int *result)
 {
-   char res[] = "msg=ChannelCloseResult\nresult-code=%d\n";
+   const char res[] = "msg=ChannelCloseResult\nresult-code=%d\n";
    int len=0;
-   unsigned char nullByte=0;
+   int config, interface, altset;
 
    *result = R_AOK;
 
@@ -823,13 +821,26 @@ int Dot4Channel::Close(char *sendBuf, int *result)
       pDev->MlcUp=0;
       memset(pDev->CA, 0, sizeof(pDev->CA));
 
-      if (pDev->NewProtocol == USB_PROTOCOL_712)
+      if (pDev->OpenFD == FD_7_1_2)
       {
-         ioctl(pDev->GetOpenFD(), LPIOC_HP_SET_CHANNEL, 78);  /* reset DOT4 (ECP channel-78) */
-         pDev->Write(pDev->GetOpenFD(), &nullByte, 1);  
-         ioctl(pDev->GetOpenFD(), LPIOC_HP_SET_CHANNEL, 0);   /* set raw mode (ECP channel-0) */
+         if (pDev->GetChannelMode() == DOT4_BRIDGE_MODE)
+         {
+            pDev->BridgeChipDown(pDev->GetOpenFD());
+         }
+         else
+         {
+            pDev->WriteECPChannel(pDev->GetOpenFD(), 78);
+            pDev->WriteECPChannel(pDev->GetOpenFD(), 0);
+         }
+      }
+
+      /* If 7/1/2 protocol is available, use it. */
+      if (pDev->OpenFD == FD_7_1_3 && pDev->GetInterface(7, 1, 2, &config, &interface, &altset) == 0)
+      {
+         pDev->ReleaseInterface(FD_7_1_3);
+         pDev->ClaimInterface(FD_7_1_2, config, interface, altset);
+         pDev->OpenFD = FD_7_1_2;
       }
-      ioctl(pDev->GetOpenFD(), LPIOC_SET_PROTOCOL, pDev->CurrentProtocol);
 
       /* Delay for back-to-back scanning using scanimage (ie: OJ 7110, OJ d135). */
       sleep(1);
@@ -842,7 +853,7 @@ int Dot4Channel::Close(char *sendBuf, int *result)
 
 int Dot4Channel::WriteData(unsigned char *data, int length, char *sendBuf, int *result)
 {
-   char res[] = "msg=ChannelDataOutResult\nresult-code=%d\nbytes-written=%d\n"; 
+   const char res[] = "msg=ChannelDataOutResult\nresult-code=%d\nbytes-written=%d\n"; 
    int ret, len, size, sLen, dlen, total=0;
    int cnt=0;
 
@@ -927,7 +938,7 @@ bugout:
  */
 int Dot4Channel::ReadData(int length, int timeout, char *sendBuf, int sendBufLength, int *result)
 {
-   char res[] = "msg=ChannelDataInResult\nresult-code=%d\n";
+   const char res[] = "msg=ChannelDataInResult\nresult-code=%d\n";
    int sendLen;
 
    *result=R_IO_ERROR;
