@@ -108,8 +108,11 @@ public:
 		"Deskjet 6500\0"
 		"Deskjet 6600\0"
 		"Deskjet 6800\0"
+        "Deskjet 6940\0"
+        "Deskjet 6980\0"
 		"deskjet 9600\0"
 		"Deskjet 9800\0"
+        "Business Inkjet 1000\0"
 		"hp business inkjet 1100\0"
    		"HP Business Inkjet 1200\0"
         "photosmart 7150\0"
@@ -128,7 +131,6 @@ public:
 		"Photosmart 8400\0"
 		"Photosmart 8700\0"
 		"Photosmart 8200\0"
-        "Business Inkjet 1000\0"
 		"Photosmart 320\0"
 		"Photosmart 370\0"
 		"Photosmart 380\0"
@@ -137,20 +139,16 @@ public:
 #ifdef APDK_MLC_PRINTER
 		"PSC 1500\0"
 		"PSC 1600\0"
-        "PSC 2100\0"              
-        "PSC 2150\0"
         "PSC 2200\0"
         "psc 2300\0"
 		"PSC 2350\0"
         "psc 2400\0"
         "psc 2500\0"
-		"PSC 2170\0"
-		"OfficeJet 6100\0"
-		"OfficeJet 6150\0"
 		"Officejet 7400\0"
 		"Officejet 7300\0"
 		"Officejet 7200\0"
 		"Officejet 6200\0"
+        "Officejet 6300\0"
         "Photosmart 2570\0"
 		"Photosmart 2600\0"
 		"Photosmart 2700\0"
