@@ -177,7 +177,7 @@ int hpijs_set_cb (void *set_cb_data, IjsServerCtx *ctx, IjsJobId job_id,
    char *tail;
    int status = 0;
    char svalue[IJS_MAX_PARAM+1];   
-   float w, h;
+   float w, h, dx, dy;
 
    /* Sanity check input value. */
    if (value_size > IJS_MAX_PARAM)
@@ -256,8 +256,12 @@ int hpijs_set_cb (void *set_cb_data, IjsServerCtx *ctx, IjsJobId job_id,
       }
       else
       {
+
+         dx = w > pSS->PaperWidth ? w - pSS->PaperWidth : pSS->PaperWidth - w;
+         dy = h > pSS->PaperHeight ? h - pSS->PaperHeight :  pSS->PaperHeight - h;
+
          /* Middle of print Job, ignore paper size if same. */
-         if (!(w == pSS->PaperWidth && h == pSS->PaperHeight))
+         if ((dx > 0.03) || (dy > 0.03))
          {
             pSS->FirstRaster = 1;  /* force new Job */
             pSS->PaperWidth = w;   /* set new paper size */
@@ -272,19 +276,19 @@ int hpijs_set_cb (void *set_cb_data, IjsServerCtx *ctx, IjsJobId job_id,
    }
    else if (!strcmp (key, "Quality:Quality"))
    {
-      pSS->Quality = strtol(svalue, &tail, 10);
+      pSS->Quality = (QUALITY_MODE) strtol(svalue, &tail, 10);
    }
    else if (!strcmp (key, "Quality:MediaType"))
    {
-      pSS->MediaType = strtol(svalue, &tail, 10);
+      pSS->MediaType = (MEDIATYPE) strtol(svalue, &tail, 10);
    }
    else if (!strcmp (key, "Quality:ColorMode"))
    {
-      pSS->ColorMode = strtol(svalue, &tail, 10);
+      pSS->ColorMode = (COLORMODE) strtol(svalue, &tail, 10);
    }
    else if (!strcmp (key, "Quality:PenSet"))
    {
-      pSS->PenSet = strtol(svalue, &tail, 10);
+      pSS->PenSet = (PEN_TYPE) strtol(svalue, &tail, 10);
    }
    else if (!strcmp (key, "Quality:FullBleed"))
    {
@@ -304,6 +308,7 @@ int hpijs_set_cb (void *set_cb_data, IjsServerCtx *ctx, IjsJobId job_id,
 int hpijs_get_cb(void *get_cb_data, IjsServerCtx *ctx, IjsJobId job_id, const char *key, char *value_buf, int value_size)
 {
    UXServices *pSS = (UXServices*)get_cb_data;
+   float        fX;
    float        fY;
 
    if (!strcmp (key, "PrintableArea"))
@@ -324,11 +329,27 @@ int hpijs_get_cb(void *get_cb_data, IjsServerCtx *ctx, IjsJobId job_id, const ch
          }
 #endif
          fY = pSS->pPC->PhysicalPageSizeY () - 1.0;
-//         return snprintf(value_buf, value_size, "%.4fx%.4f", pSS->pPC->PrintableWidth(), pSS->pPC->PhysicalPageSizeY()-1);
+
+         // SuperB size paper requires larger margins
+         if (pSS->pPC->PhysicalPageSizeY () > 18.0)
+         {
+             fY = 1.5;
+         }
+
       }
-//      else
-//         return snprintf(value_buf, value_size, "%.4fx%.4f", pSS->pPC->PrintableWidth(), pSS->pPC->PrintableHeight());
-      return (snprintf (value_buf, value_size, "%.4fx%.4f", pSS->pPC->PrintableWidth (), fY));
+
+/*
+ *      Fullbleed printing is requested and printer supports it, then
+ *      return the unadjusted physical width and height.
+ */
+
+      if ((fX = pSS->pPC->PrintableWidth ()) > pSS->PaperWidth)
+      {
+          fX = pSS->PaperWidth;
+          fY = pSS->PaperHeight;
+      }
+
+      return (snprintf (value_buf, value_size, "%.4fx%.4f", fX, fY));
    }
    else if (!strcmp (key, "PrintableTopLeft"))
    {
@@ -343,14 +364,15 @@ int hpijs_get_cb(void *get_cb_data, IjsServerCtx *ctx, IjsJobId job_id, const ch
          }
 #endif
          fY = 0.5;
-      }
-      return snprintf (value_buf, value_size, "%.4fx%.4f", pSS->pPC->PrintableStartX (), fY);
+         // SuperB size paper requires larger margins
+         if (pSS->pPC->PhysicalPageSizeY () > 18.0)
+         {
+             fY = 0.75;
+         }
 
-/*
-         return snprintf(value_buf, value_size, "%.4fx%.4f", pSS->pPC->PrintableStartX(), 0.5);
-      else
-         return snprintf(value_buf, value_size, "%.4fx%.4f", pSS->pPC->PrintableStartX(), pSS->pPC->PrintableStartY());
- */
+      }
+
+      return snprintf (value_buf, value_size, "%.4fx%.4f", pSS->pPC->PrintableStartX (), fY);
    }
    else if ((!strcmp (key, "Duplex")) || (!strcmp (key, "PS:Duplex")))
    {
