@@ -30,6 +30,13 @@
 
 
 #ifdef APDK_LJJETREADY
+/*
+ *  Not sure need HAVE_PROTOTYPES here, a user reported a compiler error under Tru64. The error
+ *  was for the assignment jerr.error_exit = Gjpeg_error; This seems to be due to JMETHOD
+ *  definition in jmorecfg.h
+ */
+
+//#define HAVE_PROTOTYPES
 
 #include "header.h"
 #include "io_defs.h"
@@ -484,6 +491,7 @@ DRIVER_ERROR HeaderLJJetReady::MapPCLMediaTypeToString (MEDIATYPE eM)
         default:
             //** unsupported media type; return error code
             assert (0);
+			err = SYSTEM_ERROR;
             break;// to be verified..
     }
 
@@ -579,7 +587,10 @@ DRIVER_ERROR LJJetReady::Encapsulate (const RASTERDATA* InputRaster, BOOL bLastP
  	pCompressor = (ModeJPEG*)GetCompressor();
 
     wCoordinate = (unsigned short int)pCompressor->GetCoordinates() - 128;
-	err = Send ((const BYTE *)&wCoordinate, sizeof(unsigned short int));
+//	err = Send ((const BYTE *)&wCoordinate, sizeof(unsigned short int));
+    res[0] = wCoordinate & 0xFF;
+    res[1] = ((wCoordinate & 0xFF00) >> 8);
+    err = Send ((const BYTE *) res, 2);
 	ERRCHECK;
 
 	BYTE JrStripHeight[] = {0xF8,0x6D,0xC1,0x80,0x00,0xF8,0x63};
@@ -823,6 +834,8 @@ BYTE* ModeJPEG::GetBuffer()
 
 extern "C"
 {
+/*
+ * These are declared in libjpeg.h, some compilers don't like declaration here as well.
 void jpeg_finish_compress (j_compress_ptr cinfo);
 JDIMENSION jpeg_write_scanlines (j_compress_ptr cinfo, JSAMPARRAY scanlines, JDIMENSION num_lines);
 void jpeg_start_compress(struct jpeg_compress_struct *,unsigned char);
@@ -832,8 +845,9 @@ void jpeg_default_colorspace(struct jpeg_compress_struct *);
 void jpeg_set_defaults(struct jpeg_compress_struct *);
 void jpeg_CreateCompress(struct jpeg_compress_struct *,int,unsigned int);
 void jpeg_destroy_compress(struct jpeg_compress_struct *);
-void jpeg_buffer_dest (j_compress_ptr cinfo, JOCTET* outbuff, void* flush_output_buffer_callback);
 struct jpeg_error_mgr * jpeg_std_error(struct jpeg_error_mgr * err);
+*/
+void jpeg_buffer_dest (j_compress_ptr cinfo, JOCTET* outbuff, void* flush_output_buffer_callback);
 }
 
 #define ConvertToGrayMacro(red, green, blue) ((unsigned char)( ( (red * 30) + (green * 59) + (blue * 11) ) / 100 ))
@@ -1159,7 +1173,7 @@ BOOL  ModeJPEG::Compress( HPLJBITMAP *pSrcBitmap,
 
     fpJPEGStart = fpJPEGBuffer;
 
-    jpeg_buffer_dest(&cinfo, fpJPEGBuffer, (void*) (ModeJPEG::jpeg_flush_output_buffer_callback));
+    jpeg_buffer_dest(&cinfo, (JOCTET *) fpJPEGBuffer, (void*) (ModeJPEG::jpeg_flush_output_buffer_callback));
     if(bGrayscaleSet)
     {
         cinfo.write_JFIF_header  =
@@ -1192,7 +1206,7 @@ BOOL  ModeJPEG::Compress( HPLJBITMAP *pSrcBitmap,
 
 	for(unsigned int nrow = 0; nrow < cinfo.image_height; nrow++)
     {
-        pRowArray[0] = pCurLine;
+        pRowArray[0] = (JSAMPROW) pCurLine;
         jpeg_write_scanlines(&cinfo, pRowArray, 1);
         pCurLine += dwScanLine;
     }
@@ -1336,7 +1350,10 @@ BOOL ModeJPEG::Process
 				}	
 
 				//Write the source width to the printer;
-				err = thePrinter->Send ((const BYTE*)&sourcewidth, sizeof(unsigned short int));
+//				err = thePrinter->Send ((const BYTE*)&sourcewidth, sizeof(unsigned short int));
+                res[0] = sourcewidth & 0x00FF;
+                res[1] = ((sourcewidth & 0xFF00) >> 8);
+                err = thePrinter->Send ((const BYTE *) res, 2);
 				ERRCHECK;
 				//  0xF8       - unsigned 8 bit attribute
 				//  0x6C       - source width attribute
@@ -1346,7 +1363,10 @@ BOOL ModeJPEG::Process
 				ERRCHECK;
 				
 				//Write the source height to the printer
-				err = thePrinter->Send ((const BYTE*)&sourceheight, sizeof(unsigned short int));
+//				err = thePrinter->Send ((const BYTE*)&sourceheight, sizeof(unsigned short int));
+                res[0] = sourceheight & 0x00FF;
+                res[1] = ((sourceheight & 0xFF00) >> 8);
+                err = thePrinter->Send ((const BYTE *) res, 2);
 				ERRCHECK;
 				// 0xF8       - unsigned 8 bit attribute
 				// 0x6B       - source height attribute
@@ -1357,7 +1377,10 @@ BOOL ModeJPEG::Process
 				
 				unsigned short int stripcount = sourceheight / MOJAVE_STRIP_HEIGHT;
 				//stripcount = 4;
-				err = thePrinter->Send ((const BYTE *)&stripcount, sizeof(stripcount));
+//				err = thePrinter->Send ((const BYTE *)&stripcount, sizeof(stripcount));
+                res[0] = stripcount & 0x00FF;
+                res[1] = ((stripcount & 0xFF00) >> 8);
+                err = thePrinter->Send ((const BYTE *) res, 2);
 				ERRCHECK;
 				//0xF8       - unsigned 8 bit attribute
 				//0x93       - special attribute 1 for strip count  
@@ -1423,6 +1446,7 @@ BOOL ModeJPEG::Process
 				err = thePrinter->Send ((const BYTE *)JrQTSeq, sizeof(JrQTSeq));
 				ERRCHECK;
 
+#ifdef APDK_LITTLE_ENDIAN
 				//VWritePrinter((VOID*) pQTableInfo->qtable0, sizeof(DWORD) * QTABLE_SIZE);
 				err = thePrinter->Send ((const BYTE *)qTableInfo.qtable0, sizeof(DWORD) * QTABLE_SIZE);
 				ERRCHECK;
@@ -1435,7 +1459,35 @@ BOOL ModeJPEG::Process
 				//VWritePrinter((VOID*) pQTableInfo->qtable2, sizeof(DWORD) * QTABLE_SIZE);
 				err = thePrinter->Send ((const BYTE *)qTableInfo.qtable2, sizeof(DWORD) * QTABLE_SIZE);
 				ERRCHECK;
-           
+#else
+                BYTE    szStr[sizeof (DWORD) * QTABLE_SIZE * 3];
+                BYTE    *p;
+                p = szStr;
+                for (int i = 0; i < QTABLE_SIZE; i++)
+                {
+                    *p++ = qTableInfo.qtable0[i] & 0xFF;
+                    *p++ = (qTableInfo.qtable0[i] >> 8) & 0xFF;
+                    *p++ = (qTableInfo.qtable0[i] >> 16) & 0xFF;
+                    *p++ = (qTableInfo.qtable0[i] >> 24) & 0xFF;
+                }
+                for (int i = 0; i < QTABLE_SIZE; i++)
+                {
+                    *p++ = qTableInfo.qtable1[i] & 0xFF;
+                    *p++ = (qTableInfo.qtable1[i] >> 8) & 0xFF;
+                    *p++ = (qTableInfo.qtable1[i] >> 16) & 0xFF;
+                    *p++ = (qTableInfo.qtable1[i] >> 24) & 0xFF;
+                }
+                for (int i = 0; i < QTABLE_SIZE; i++)
+                {
+                    *p++ = qTableInfo.qtable2[i] & 0xFF;
+                    *p++ = (qTableInfo.qtable2[i] >> 8) & 0xFF;
+                    *p++ = (qTableInfo.qtable2[i] >> 16) & 0xFF;
+                    *p++ = (qTableInfo.qtable2[i] >> 24) & 0xFF;
+                }
+                err = thePrinter->Send ((const BYTE *) szStr, 3 * sizeof (DWORD) * QTABLE_SIZE);
+                ERRCHECK;
+
+#endif
 				// Start of JPEG Control
 				// 0x8001 JPEG Control register
 				// size - unsigned 32 bit number 0x0000_002C
